# Generated by roxygen2: do not edit by hand

export("%>%")
export(AverageWAgg)
export(BayesianWAgg)
export(DistributionWAgg)
export(ExtremisationWAgg)
export(IntervalWAgg)
export(LinearWAgg)
export(ReasoningWAgg)
export(ShiftingWAgg)
export(confidence_score_evaluation)
export(confidence_score_heatmap)
export(confidence_score_ridgeplot)
export(method_placeholder)
export(postprocess_judgements)
export(preprocess_judgements)
export(weight_asym)
export(weight_interval)
export(weight_nIndivInterval)
export(weight_outlier)
export(weight_reason)
export(weight_reason2)
export(weight_varIndivInterval)
import(mathjaxr)
importFrom(DescTools,BrierScore)
importFrom(MLmetrics,Accuracy)
importFrom(insight,format_capitalize)
importFrom(magrittr,"%>%")
importFrom(precrec,auc)
importFrom(precrec,evalmod)
importFrom(stats,cor)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,var)
