## ---- include=FALSE-----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----setup, message=FALSE, warning=FALSE--------------------------------------
library(aggreCAT)
library(tidyverse)

## ----data_ratings-sample, message=TRUE, results='hold'------------------------
aggreCAT::data_ratings %>%
  dplyr::filter(paper_id == dplyr::first(paper_id),
                user_name == dplyr::first(user_name)) %>%
  head()


## ----data_supp_quiz-sample, message=TRUE, results='hold'----------------------
aggreCAT::data_supp_quiz

## ----data_supp_reasons-sample-------------------------------------------------
aggreCAT::data_supp_reasons %>%
  glimpse()

## ----data_supp_priors-sample--------------------------------------------------
aggreCAT::data_supp_priors

