#' aggreCAT: mathematically aggregating expert judgements
#'
#' To learn more about \pkg{aggreCAT}, start with the vignettes: \code{vignette(package = "aggreCAT")}
#'
#' @docType package
#' @name aggreCAT
#' @import mathjaxr
#'
#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL
