% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{data_supp_quiz}
\alias{data_supp_quiz}
\title{A table of scores on the quiz to assess prior knowledge, to be fed into the QuizWAgg aggregation method}
\format{
A tibble 19 rows and 2 columns
\describe{
\item{user_name}{factor for anonymized IDs for each participant}
\item{quiz_score}{numeric for the participant's score on the quiz (min of 0, max of 16, NA if no questions answered)}
\item{quiz_score_even}{numeric quiz scores where all questions are weighted equally (the original quiz score assigned only half marks for true/false questions)}
\item{quiz_score_stats}{numeric participant score based only on questions pertaining to statistics}
}
}
\usage{
data_supp_quiz
}
\description{
A table of scores on the quiz to assess prior knowledge, to be fed into the QuizWAgg aggregation method
}
\keyword{datasets}
